@@ -1,5 +1,4 @@
-""" Definition of an entry-point function for setting up and initializing a
-FOCA based microservice."""
+"""Entry point for setting up and initializing a FOCA-based microservice."""
 
 import logging
 from typing import Optional
@@ -19,14 +18,14 @@ logger = logging.getLogger(__name__)
 
 
 def foca(config: Optional[str] = None) -> App:
-    """ Initialize a FOCA-based microservice.
+    """Set up and initialize FOCA-based microservice.
 
     Args:
-        config: Path to a YAML application configuration file. For required
-            YAML file structure, see :py:class:`foca.models.config.Config()`.
+        config: Path to application configuration file in YAML format. Cf.
+            :py:class:`foca.models.config.Config` for required file structure.
 
     Returns:
-        Connexion app instance.
+        Connexion application instance.
     """
 
     # Parse config parameters and format logging
@@ -46,8 +45,11 @@ def foca(config: Optional[str] = None) -> App:
     logger.info(f"Error handler registered.")
 
     # Enable cross-origin resource sharing
-    enable_cors(cnx_app.app)
-    logger.info(f"CORS enabled.")
+    if(conf.security.cors.enabled is True):
+        enable_cors(cnx_app.app)
+        logger.info(f"CORS enabled.")
+    else:
+        logger.info(f"CORS not enabled.")
 
     # Register OpenAPI specs
     if conf.api.specs:
